@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import base64
 import hashlib
 import importlib.metadata
@@ -6,10 +8,8 @@ import logging
 import pkgutil
 import re
 from contextlib import suppress
-from importlib.abc import PathEntryFinder
 from pathlib import Path
-from types import ModuleType
-from typing import Dict, Iterator, List, Literal, Optional, Tuple, Type, Union
+from typing import TYPE_CHECKING, Literal, TypeAlias, TypedDict
 
 import streamlink.plugins
 from streamlink.options import Argument, Arguments
@@ -19,10 +19,11 @@ from streamlink.plugin.plugin import _PLUGINARGUMENT_TYPE_REGISTRY, NO_PRIORITY,
 from streamlink.utils.module import exec_module, get_finder
 
 
-try:
-    from typing import TypeAlias, TypedDict  # type: ignore[attr-defined]
-except ImportError:  # pragma: no cover
-    from typing_extensions import TypeAlias, TypedDict
+if TYPE_CHECKING:
+    from collections.abc import Iterator, Mapping
+    from types import ModuleType
+
+    from _typeshed.importlib import PathEntryFinderProtocol
 
 
 log = logging.getLogger(".".join(__name__.split(".")[:-1]))
@@ -55,11 +56,11 @@ class StreamlinkPlugins:
 
     def __init__(self, builtin: bool = True, lazy: bool = True):
         # Loaded plugins
-        self._plugins: Dict[str, Type[Plugin]] = {}
+        self._plugins: dict[str, type[Plugin]] = {}
 
         # Data of built-in plugins which can be loaded lazily
-        self._matchers: Dict[str, Matchers] = {}
-        self._arguments: Dict[str, Arguments] = {}
+        self._matchers: dict[str, Matchers] = {}
+        self._arguments: dict[str, Arguments] = {}
 
         # Attempt to load built-in plugins lazily first
         if builtin and lazy:
@@ -73,11 +74,11 @@ class StreamlinkPlugins:
         if builtin and not lazy:
             self.load_builtin()
 
-    def __getitem__(self, item: str) -> Type[Plugin]:
+    def __getitem__(self, item: str) -> type[Plugin]:
         """Access a loaded plugin class by name"""
         return self._plugins[item]
 
-    def __setitem__(self, key: str, value: Type[Plugin]) -> None:
+    def __setitem__(self, key: str, value: type[Plugin]) -> None:
         """Add/override a plugin class by name"""
         self._plugins[key] = value
 
@@ -89,11 +90,11 @@ class StreamlinkPlugins:
         """Check if a plugin is loaded"""
         return item in self._plugins
 
-    def get_names(self) -> List[str]:
+    def get_names(self) -> list[str]:
         """Get a list of the names of all available plugins"""
         return sorted(self._plugins.keys() | self._matchers.keys())
 
-    def get_loaded(self) -> Dict[str, Type[Plugin]]:
+    def get_loaded(self) -> dict[str, type[Plugin]]:
         """Get a mapping of all loaded plugins"""
         return dict(self._plugins)
 
@@ -101,14 +102,14 @@ class StreamlinkPlugins:
         """Load Streamlink's built-in plugins"""
         return self.load_path(_PLUGINS_PATH)
 
-    def load_path(self, path: Union[Path, str]) -> bool:
+    def load_path(self, path: str | Path) -> bool:
         """Load plugins from a custom directory"""
         plugins = self._load_plugins_from_path(path)
         self.update(plugins)
 
         return bool(plugins)
 
-    def update(self, plugins: Dict[str, Type[Plugin]]):
+    def update(self, plugins: Mapping[str, type[Plugin]]):
         """Add/override loaded plugins"""
         self._plugins.update(plugins)
 
@@ -116,35 +117,35 @@ class StreamlinkPlugins:
         """Remove all loaded plugins from the session"""
         self._plugins.clear()
 
-    def iter_arguments(self) -> Iterator[Tuple[str, Arguments]]:
+    def iter_arguments(self) -> Iterator[tuple[str, Arguments]]:
         """Iterate through all plugins and their :class:`Arguments <streamlink.options.Arguments>`"""
         yield from (
             (name, plugin.arguments)
             for name, plugin in self._plugins.items()
             if plugin.arguments
-        )
+        )  # fmt: skip
         yield from (
             (name, arguments)
             for name, arguments in self._arguments.items()
             if arguments and name not in self._plugins
-        )
+        )  # fmt: skip
 
-    def iter_matchers(self) -> Iterator[Tuple[str, Matchers]]:
+    def iter_matchers(self) -> Iterator[tuple[str, Matchers]]:
         """Iterate through all plugins and their :class:`Matchers <streamlink.plugin.plugin.Matchers>`"""
         yield from (
             (name, plugin.matchers)
             for name, plugin in self._plugins.items()
             if plugin.matchers
-        )
+        )  # fmt: skip
         yield from (
             (name, matchers)
             for name, matchers in self._matchers.items()
             if matchers and name not in self._plugins
-        )
+        )  # fmt: skip
 
-    def match_url(self, url: str) -> Optional[Tuple[str, Type[Plugin]]]:
+    def match_url(self, url: str) -> tuple[str, type[Plugin]] | None:
         """Find a matching plugin by URL and load plugins which haven't been loaded yet"""
-        match: Optional[str] = None
+        match: str | None = None
         priority: int = NO_PRIORITY
 
         for name, matchers in self.iter_matchers():
@@ -167,20 +168,20 @@ class StreamlinkPlugins:
 
         return match, self._plugins[match]
 
-    def _load_plugin_from_path(self, name: str, path: Path) -> Optional[Tuple[ModuleType, Type[Plugin]]]:
+    def _load_plugin_from_path(self, name: str, path: Path) -> tuple[ModuleType, type[Plugin]] | None:
         finder = get_finder(path)
 
         return self._load_plugin_from_finder(name, finder)
 
-    def _load_plugins_from_path(self, path: Union[Path, str]) -> Dict[str, Type[Plugin]]:
-        plugins: Dict[str, Type[Plugin]] = {}
+    def _load_plugins_from_path(self, path: str | Path) -> dict[str, type[Plugin]]:
+        plugins: dict[str, type[Plugin]] = {}
         for finder, name, _ in pkgutil.iter_modules([str(path)]):
             lookup = self._load_plugin_from_finder(name, finder=finder)  # type: ignore[arg-type]
             if lookup is None:
                 continue
             mod, plugin = lookup
             if (name in self._plugins or name in self._matchers) and mod.__file__:
-                with open(mod.__file__, "rb") as fh:
+                with Path(mod.__file__).open("rb") as fh:
                     sha256 = hashlib.sha256(fh.read())
                 log.info(f"Plugin {name} is being overridden by {mod.__file__} (sha256:{sha256.hexdigest()})")
             plugins[name] = plugin
@@ -188,10 +189,10 @@ class StreamlinkPlugins:
         return plugins
 
     @staticmethod
-    def _load_plugin_from_finder(name: str, finder: PathEntryFinder) -> Optional[Tuple[ModuleType, Type[Plugin]]]:
+    def _load_plugin_from_finder(name: str, finder: PathEntryFinderProtocol) -> tuple[ModuleType, type[Plugin]] | None:
         try:
             # set the full plugin module name, even for sideloaded plugins
-            mod = exec_module(finder, f"streamlink.plugins.{name}")
+            mod = exec_module(finder, f"streamlink.plugins.{name}", override=True)
         except ImportError as err:
             log.exception(f"Failed to load plugin {name} from {err.path}\n")
             return None
@@ -202,46 +203,49 @@ class StreamlinkPlugins:
         return mod, mod.__plugin__
 
 
-_TListOfConstants: TypeAlias = List[Union[None, bool, int, float, str]]
-_TConstantOrListOfConstants: TypeAlias = Union[None, bool, int, float, str, _TListOfConstants]
-_TMappingOfConstantOrListOfConstants: TypeAlias = Dict[str, _TConstantOrListOfConstants]
+_RE_STRIP_JSON_COMMENTS = re.compile(rb"^(?:\s*//[^\n]*\n+)+")
+
+if TYPE_CHECKING:
+    _TListOfConstants: TypeAlias = list[bool | int | float | str | None]
+    _TConstantOrListOfConstants: TypeAlias = bool | int | float | str | _TListOfConstants | None
+    _TMappingOfConstantOrListOfConstants: TypeAlias = dict[str, _TConstantOrListOfConstants]
 
 
 class _TPluginMatcherData(TypedDict):
     pattern: str
-    flags: Optional[int]
-    priority: Optional[int]
-    name: Optional[str]
+    flags: int | None
+    priority: int | None
+    name: str | None
 
 
 class _TPluginArgumentData(TypedDict):
     name: str
-    action: Optional[str]
-    nargs: Optional[Union[int, Literal["*", "?", "+"]]]
+    action: str | None
+    nargs: int | Literal["*", "?", "+"] | None
     const: _TConstantOrListOfConstants
     default: _TConstantOrListOfConstants
-    type: Optional[str]
-    type_args: Optional[_TListOfConstants]
-    type_kwargs: Optional[_TMappingOfConstantOrListOfConstants]
-    choices: Optional[_TListOfConstants]
-    required: Optional[bool]
-    help: Optional[str]
-    metavar: Optional[Union[str, List[str]]]
-    dest: Optional[str]
-    requires: Optional[Union[str, List[str]]]
-    prompt: Optional[str]
-    sensitive: Optional[bool]
-    argument_name: Optional[str]
+    type: str | None
+    type_args: _TListOfConstants | None
+    type_kwargs: _TMappingOfConstantOrListOfConstants | None
+    choices: _TListOfConstants | None
+    required: bool | None
+    help: str | None
+    metavar: str | list[str] | None
+    dest: str | None
+    requires: str | list[str] | None
+    prompt: str | None
+    sensitive: bool | None
+    argument_name: str | None
 
 
 class _TPluginData(TypedDict):
-    matchers: List[_TPluginMatcherData]
-    arguments: List[_TPluginArgumentData]
+    matchers: list[_TPluginMatcherData]
+    arguments: list[_TPluginArgumentData]
 
 
 class StreamlinkPluginsData:
     @classmethod
-    def load(cls) -> Optional[Tuple[Dict[str, Matchers], Dict[str, Arguments]]]:
+    def load(cls) -> tuple[dict[str, Matchers], dict[str, Arguments]] | None:
         # specific errors get logged, others are ignored intentionally
         with suppress(Exception):
             content = _PLUGINSDATA_PATH.read_bytes()
@@ -274,8 +278,9 @@ class StreamlinkPluginsData:
             raise Exception
 
     @classmethod
-    def _parse(cls, content: bytes) -> Tuple[Dict[str, Matchers], Dict[str, Arguments]]:
-        data: Dict[str, _TPluginData] = json.loads(content)
+    def _parse(cls, content: bytes) -> tuple[dict[str, Matchers], dict[str, Arguments]]:
+        content = _RE_STRIP_JSON_COMMENTS.sub(b"", content)
+        data: dict[str, _TPluginData] = json.loads(content)
 
         try:
             matchers = cls._build_matchers(data)
@@ -292,13 +297,13 @@ class StreamlinkPluginsData:
         return matchers, arguments
 
     @classmethod
-    def _build_matchers(cls, data: Dict[str, _TPluginData]) -> Dict[str, Matchers]:
+    def _build_matchers(cls, data: dict[str, _TPluginData]) -> dict[str, Matchers]:
         res = {}
         for pluginname, plugindata in data.items():
             matchers = Matchers()
             for m in plugindata.get("matchers") or []:
                 matcher = cls._build_matcher(m)
-                matchers.register(matcher)
+                matchers.add(matcher)
 
             res[pluginname] = matchers
 
@@ -313,7 +318,7 @@ class StreamlinkPluginsData:
         )
 
     @classmethod
-    def _build_arguments(cls, data: Dict[str, _TPluginData]) -> Dict[str, Arguments]:
+    def _build_arguments(cls, data: dict[str, _TPluginData]) -> dict[str, Arguments]:
         res = {}
         for pluginname, plugindata in data.items():
             if not plugindata.get("arguments"):
@@ -328,16 +333,16 @@ class StreamlinkPluginsData:
         return res
 
     @staticmethod
-    def _build_argument(data: _TPluginArgumentData) -> Optional[Argument]:
+    def _build_argument(data: _TPluginArgumentData) -> Argument | None:
         name: str = data.get("name")  # type: ignore[assignment]
-        _typedata = data.get("type")
-        if not _typedata:
-            _type = None
-        elif _type := _PLUGINARGUMENT_TYPE_REGISTRY.get(_typedata):
-            _type_args = data.get("type_args") or ()
-            _type_kwargs = data.get("type_kwargs") or {}
-            if _type_args or _type_kwargs:
-                _type = _type(*_type_args, **_type_kwargs)
+        type_data = data.get("type")
+        if not type_data:
+            argument_type = None
+        elif argument_type := _PLUGINARGUMENT_TYPE_REGISTRY.get(type_data):
+            type_args = data.get("type_args") or ()
+            type_kwargs = data.get("type_kwargs") or {}
+            if type_args or type_kwargs:
+                argument_type = argument_type(*type_args, **type_kwargs)
         else:
             return None
 
@@ -347,7 +352,7 @@ class StreamlinkPluginsData:
             nargs=data.get("nargs"),
             const=data.get("const"),
             default=data.get("default"),
-            type=_type,
+            type=argument_type,
             choices=data.get("choices"),
             required=data.get("required") or False,
             help=data.get("help"),
